@@ -1,11 +1,11 @@
 from pydantic import BaseModel, root_validator
 from typing import Optional
 
-from captur_ml_sdk.dtypes.interfaces.MLMetaRequest import ModelMetaRequest
-from captur_ml_sdk.dtypes.interfaces.MLPredictRequest import ModelPredictRequest
-from captur_ml_sdk.dtypes.interfaces.MLLivePredictRequest import ModelLivePredictRequest
-from captur_ml_sdk.dtypes.interfaces.MLTrainRequest import ModelTrainRequest
-from captur_ml_sdk.dtypes.interfaces.MLEvalRequest import ModelEvaluateRequest
+from captur_ml_sdk.dtypes.interfaces.MLGateway.MLMetaRequest import ModelMetaRequest
+from captur_ml_sdk.dtypes.interfaces.MLGateway.MLPredictRequest import ModelPredictRequest
+from captur_ml_sdk.dtypes.interfaces.MLGateway.MLLivePredictRequest import ModelLivePredictRequest
+from captur_ml_sdk.dtypes.interfaces.MLGateway.MLTrainRequest import ModelTrainRequest
+from captur_ml_sdk.dtypes.interfaces.MLGateway.MLEvalRequest import ModelEvaluateRequest
 
 
 class MLGatewayRequest(BaseModel):
